<?php
/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik_Plugins
 * @package Groups
 */
namespace Piwik\Plugins\Groups;


use Piwik\Common;
use Piwik\Piwik;
use Piwik\Plugin\ControllerAdmin;
use Piwik\Plugins\Groups\API as APIGroups;
use Piwik\View;


/**
 * Groups Controller
 */
class Controller extends \Piwik\Plugin\Controller
{
    
    // "index" action. This is the main "Groups" page.
    public function index()
    {
        APIGroups::getInstance()->checkUserIsAllowedToAccessGroups();
        
        $view = new View('@Groups/index.twig');
        $this->setBasicVariablesView($view);
        ControllerAdmin::setBasicVariablesAdminView($view);
        Controller::setBasicVariablesView($view);
        
        $groups = API::getInstance()->getGroupsFromUser();
        foreach ($groups as $key => $group) {
            // get Member Count
            $members = APIGroups::getInstance()->getGroupMembers($group['id']);
            $groups[$key]['memberCount'] = count($members);
            
            // get Website Count
            $sites = APIGroups::getInstance()->getGroupSites($group['id']);
            $groups[$key]['siteCount'] = count($sites);
        } 
        
        $view->groups = $groups;
        $view->groupsCount = count($groups);
        $view->canAddGroup = Piwik::hasUserSuperUserAccess();
        $view->isAdminOfAllGroups = Piwik::hasUserSuperUserAccess();
        
        return $view->render();
    }
    
    // "membersOfGroup" action. Clicking "Show Members" for a group links to this view.
    // A Group admin (or SuperUser) can add users to a group here, or remove them from it.
    public function membersOfGroup()
    {
        APIGroups::getInstance()->checkUserIsAllowedToAccessGroups();
        
        $view = new View('@Groups/membersOfGroup.twig');
        $this->setBasicVariablesView($view);
        ControllerAdmin::setBasicVariablesAdminView($view);
        Controller::setBasicVariablesView($view);
        
        $groupId = Common::getRequestVar('groupId', 0, 'int');
        $group = API::getInstance()->getGroupFromUser($groupId);
        $members = API::getInstance()->getGroupMembers($groupId);

        $view->group = $group;
        $view->members = $members;
        $view->memberCount = count($members);
        
        return $view->render();
    }
    
    // "siesForGroup" action. Clicking "Show Websites" for a group links to this view.
    // A Group admin (or SuperUser) can add websites to a group here, or remove them.
    public function sitesForGroup()
    {
        APIGroups::getInstance()->checkUserIsAllowedToAccessGroups();
        
        $view = new View('@Groups/sitesForGroup.twig');
        $this->setBasicVariablesView($view);
        ControllerAdmin::setBasicVariablesAdminView($view);
        Controller::setBasicVariablesView($view);
        
        $groupId = Common::getRequestVar('groupId', 0, 'int');
        $group = API::getInstance()->getGroupFromUser($groupId);
        $sites = $groups = array();
        
        $view->groups = $groups;
        $view->group = $group;
        $view->sites = $sites;
        $view->canAddGroup = true;
        $view->isAdminOfAllGroups = true;
        $view->canAddUser = Piwik::hasUserSuperUserAccess();

        return $view->render();
    }
}
