<?php
/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik_Plugins
 * @package Groups
 */
namespace Piwik\Plugins\Groups;

use Piwik\Common;
use Piwik\Db;
use Piwik\DbHelper;
use Piwik\Menu\MenuAdmin;
use Piwik\Piwik;
use Piwik\Plugins\Groups\API as APIGroups;

define("DROP_ALL_SETTINGS_ON_DEACTIVATION", true);

/**
*
* @package Groups
*/
class Groups extends \Piwik\Plugin
{
    public function install()
    {
        DbHelper::createTable('group', 
           "id INT NOT NULL AUTO_INCREMENT,
            name VARCHAR( 100 ) NOT NULL,
            maxsites INT NOT NULL DEFAULT 0,
            PRIMARY KEY ( id )");
        DbHelper::createTable('group_access',
           "group_id INT NOT NULL,
            login VARCHAR( 100 ) NOT NULL,
            access VARCHAR( 10 ) NOT NULL,
            PRIMARY KEY ( group_id, login )");
    }

    public function uninstall()
    {
        Db::dropTables(Common::prefixTable('group'));
        Db::dropTables(Common::prefixTable('group_access'));
    }
    
    
    public function activate()
    {
        if (!DROP_ALL_SETTINGS_ON_DEACTIVATION) return true;
        return $this->install();
    }
    
    public function deactivate()
    {
        if (!DROP_ALL_SETTINGS_ON_DEACTIVATION) return true;
        return $this->uninstall();
    }
    
    
    /**
     * @see Piwik\Plugin::getListHooksRegistered
     */
    public function getListHooksRegistered()
    {
        return array(
            'Menu.Admin.addItems' => 'addMenu',
            'AssetManager.getJavaScriptFiles' => 'getJsFiles',
            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
            'Translate.getClientSideTranslationKeys' => 'getClientSideTranslationKeys',
        );
    }

    /**
    * Add admin menu items
    */
    public function addMenu()
    {
        MenuAdmin::getInstance()->add('CoreAdminHome_MenuManage', 'Groups_Groups',
            array('module' => 'Groups', 'action' => 'index'),
            APIGroups::getInstance()->isUserAllowedToAccessGroups(),
            2);
    }
    
    /**
    * Get JavaScript files
    */
    public function getJsFiles(&$jsFiles)
    {
        $jsFiles[] = 'plugins/Groups/javascripts/Groups.js';
    }
    
    /**
    * Get CSS files
    */
    public function getStylesheetFiles(&$stylesheets)
    {
        $stylesheets[] = "plugins/Groups/stylesheets/Groups.less";
    }
    
     public function getClientSideTranslationKeys(&$translationKeys)
    {
        $translationKeys[] = 'Groups_OneGroupAtATime';
        $translationKeys[] = 'Groups_ZeroForUnlimited';
        $translationKeys[] = 'Groups_DeleteConfirmGroup';
        $translationKeys[] = 'Groups_DeleteConfirmMember';
    }
}
