/**
 * Piwik - Open source web analytics
 *
 * @link http://piwik.org
 * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
 *
 * @category Piwik_Plugins
 * @package Groups
 */
console.log("Groups.js");
function Groups() {

    var groupBeingEdited = false;
    var groupBeingEditedName = '';
    var memberBeingEdited = false;
    var memberBeingEditedName = '';
    
    this.init = function () {
        
        
        /**
        * Editing GROUPS
        */
        // Click handler for "Add a new group" links; insert a "New Group" row into the table.
        $('.addRowGroup').click(function () {
            piwikHelper.hideAjaxError();
            $('.addRowGroup').toggle();
            
            var excludedUserAgentCell = '';
            if ($('#exclude-user-agent-header').is(':visible')) {
                excludedUserAgentCell = '<td><textarea cols="20" rows="4" id="excludedUserAgents"></textarea><br />' + excludedUserAgentsHelp + '</td>';
            }

            var numberOfRows = $('table#editGroups')[0].rows.length;
            var newRowId = 'rowNew' + numberOfRows;
            var submitButtonHtml = '<input type="submit" class="addgroup submit" value="' + _pk_translate('General_Save') + '" />';
            $($.parseHTML(' <tr id="' + newRowId + '">\
                <td>&nbsp;</td>\
                <td><input id="groupName" value="" placeholder="Enter Group Name" size="25" /></td>\
                <td><input id="maxsites" value="0"></textarea><br />Enter <strong>0</strong> for unlimited.</td>\
                <td>' + submitButtonHtml + '</td>\
                <td><span class="cancel link_but">' + sprintf(_pk_translate('General_OrCancel'), "", "") + '</span></td>\
                <td></td>\
                <td></td>\
            </tr>'))
                .appendTo('#editGroups')
            ;

            $('.addgroup').click(function () {
                sendAddGroupAJAX($('tr#' + newRowId));
            });

            $('.cancel').click(function () {
                piwikHelper.hideAjaxError();
                $(this).parents('tr').remove();
                $('.addRowGroup').toggle();
            });
            return false;
        });
        
        // Click handler for "Edit" buttons.
        var alreadyEdited = [];
        $('.editGroup')
            .click(function () {
            
                // Ensure that only one group is edited at a time (since only one set of changes can be saved).
                piwikHelper.hideAjaxError();
                var idRow = $(this).attr('id');
                if (alreadyEdited[idRow] == 1) return;
                if (groupBeingEdited) {
                    $('#alert').find('h2').text(sprintf(_pk_translate('Groups_OneGroupAtATime'), '"' + groupBeingEditedName + '"'));
                    piwikHelper.modalConfirm('#alert', {});
                    return;
                }
                groupBeingEdited = true;
                alreadyEdited[idRow] = 1;
                
                // Do the appropriate actions for each cell in this row, to enter "Edit mode".
                $('tr#' + idRow + ' *').each(
                    function (i, n) {
                        
                        var contentBefore = $(n).html();
                        
                        if ($(n).hasClass('groupName')) {
                            // make the Name field editable, unbind click handler.
                            groupBeingEditedName = contentBefore;
                            var contentAfter = '<input id="groupName" value="' + piwikHelper.htmlEntities( piwikHelper.htmlDecode(contentBefore))+ '" size="25" />';

                            var inputSave = $('<br/><input style="margin-top:50px" type="submit" class="submit" value="' + _pk_translate('General_Save') + '" />')
                                .click(function () { submitUpdate($(this).parent()); });
                            $(n)
                                .html(contentAfter)
                                .keypress(submitOnEnter)
                                .unbind('click');
                        }
                        else if ($(n).hasClass('maxsites')) {
                            // make the Max Sites field editable, unbind click handler.
                            var contentAfter = '<input id="maxsites" value="' + piwikHelper.htmlEntities( piwikHelper.htmlDecode(contentBefore))+ '" size="15" />'
                                            +'<br>'+sprintf(_pk_translate('Groups_ZeroForUnlimited'), "<strong>", "</strong>");
                            $(n).html(contentAfter)
                                .keypress(submitOnEnter)
                                .unbind('click');
                        }
                        else if ($(n).hasClass('edit')) {
                            // change the Edit button to a Save button (and change click handler to submit + reload instead of deleting)
                            var contentAfter = $('<span>'+sprintf(_pk_translate('General_OrCancel'), "", "")+'</span>');
                            $(n).html(contentAfter).unbind('click').click(function () { piwikHelper.refreshAfter(0); });
                        }
                        else if ($(n).hasClass('delete')) {
                            // change the Delete button to a Cancel button (and change click handler to reload page instead of deleting)
                            var contentAfter = $('<span>'+sprintf(_pk_translate('General_OrCancel'), "", "")+'</span>');
                            $(n).html(contentAfter).unbind('click').click(function () { piwikHelper.refreshAfter(0); });;
                        }
                    }
                );
                $(this)
                    .toggle()
                    .parent()
                    .prepend($('<input type="submit" class="updateSite submit" value="' + _pk_translate('General_Save') + '" />')
                        .click(function () { sendUpdateGroupAJAX($('tr#' + idRow)); })
                    );
            });
            
        // Click handler for "Delete" buttons; ask for confirmation and then delete the group.
        $('.deleteGroup').click(function () {
                piwikHelper.hideAjaxError();
                var idRow = $(this).attr('id');
                var nameToDelete = $(this).parent().parent().find('input.groupName').val() || $(this).parent().parent().find('td.groupName').html();
                var idgroupToDelete = $(this).parent().parent().find('.groupId').html();

                $('#confirm').find('h2').text(sprintf(_pk_translate('Groups_DeleteConfirmGroup'), '"' + nameToDelete + '" (id = ' + idgroupToDelete + ')'));
                piwikHelper.modalConfirm('#confirm', { yes: function () {

                    sendDeleteGroupAJAX(idgroupToDelete);
                }});
            }
        );
        

        $('td.editableGroup').click(function (event) {
            $(this).parent().find('.editGroup').click();
        });
        
        
        /**
        * Editing GROUP MEMBERS
        */
        // Click handler for "Add a new user" links; insert a "New User" row into the table.
        $('.addRowMember').click(function () {
            piwikHelper.hideAjaxError();
            $('.addRowMember').toggle();
            
            var numberOfRows = $('table#editMembers')[0].rows.length;
            var newRowId = 'rowNew' + numberOfRows;
            var submitButtonHtml = '<input type="submit" class="adduser submit" value="' + _pk_translate('General_Save') + '" />';
            $($.parseHTML(' <tr id="' + newRowId + '">\
                <td><input id="login" value="" placeholder="Enter User Name" size="25" /></td>\
                <td><select id="access"><option value="view">view</option><option value="admin">admin</option></select></td>\
                <td>' + submitButtonHtml + '</td>\
                <td><span class="cancel link_but">' + sprintf(_pk_translate('General_OrCancel'), "", "") + '</span></td>\
            </tr>'))
                .appendTo('#editMembers')
            ;

            $('.adduser').click(function () {
                sendAddMemberAJAX($('tr#' + newRowId));
            });

            $('.cancel').click(function () {
                piwikHelper.hideAjaxError();
                $(this).parents('tr').remove();
                $('.addRowMember').toggle();
            });
            return false;
        });
        
        // Click handler for "Edit" buttons.
        var alreadyEdited = [];
        $('.editMember')
            .click(function () {
            
                // Ensure that only one member is edited at a time (since only one set of changes can be saved).
                piwikHelper.hideAjaxError();
                var idRow = $(this).attr('id');
                if (alreadyEdited[idRow] == 1) return;
                if (groupBeingEdited) {
                    $('#alert').find('h2').text(sprintf(_pk_translate('Groups_OneMemberAtATime'), '"' + memberBeingEditedName + '"'));
                    piwikHelper.modalConfirm('#alert', {});
                    return;
                }
                groupBeingEdited = true;
                alreadyEdited[idRow] = 1;
                
                // Do the appropriate actions for each cell in this row, to enter "Edit mode".
                $('tr#' + idRow + ' *').each(
                    function (i, n) {
                        
                        var contentBefore = $(n).html();
                        
                        if ($(n).hasClass('access')) {
                            // make the Name field editable, unbind click handler.
                            var sel_admin, sel_view;
                            switch (contentBefore) {
                                case 'admin':
                                    sel_admin = "selected";
                                    break;
                                case 'view':
                                default:
                                    sel_view = "selected";
                            }
                            
                            var contentAfter = '<select id="access"><option value="view"'+sel_view+'>view</option><option value="admin"'+sel_admin+'>admin</option></select>';

                            var inputSave = $('<br/><input style="margin-top:50px" type="submit" class="submit" value="' + _pk_translate('General_Save') + '" />')
                                .click(function () { submitUpdate($(this).parent()); });
                            $(n)
                                .html(contentAfter)
                                .keypress(submitOnEnter)
                                .unbind('click');
                        }
                        else if ($(n).hasClass('edit')) {
                            // change the Edit button to a Save button (and change click handler to submit + reload instead of deleting)
                            var contentAfter = $('<span>'+sprintf(_pk_translate('General_OrCancel'), "", "")+'</span>');
                            $(n).html(contentAfter).unbind('click').click(function () { piwikHelper.refreshAfter(0); });
                        }
                        else if ($(n).hasClass('delete')) {
                            // change the Delete button to a Cancel button (and change click handler to reload page instead of deleting)
                            var contentAfter = $('<span>'+sprintf(_pk_translate('General_OrCancel'), "", "")+'</span>');
                            $(n).html(contentAfter).unbind('click').click(function () { piwikHelper.refreshAfter(0); });;
                        }
                    }
                );
                $(this)
                    .toggle()
                    .parent()
                    .prepend($('<input type="submit" class="updateSite submit" value="' + _pk_translate('General_Save') + '" />')
                        .click(function () { sendUpdateMemberAJAX($('tr#' + idRow)); })
                    );
            });

        // Click handler for "Delete" buttons; ask for confirmation and then delete the group.
        $('.deleteMember').click(function () {
                piwikHelper.hideAjaxError();
                var idRow = $(this).attr('id');

                $('#confirm').find('h2').text(sprintf(_pk_translate('Groups_DeleteConfirmMember'), '"' + $(this).parent().parent().find('.login').html() + '"'));
                piwikHelper.modalConfirm('#confirm', { yes: function () {

                    sendDeleteMemberAJAX($('tr#' + idRow));
                }});
            }
        );
        
        /**
        * Editing GROUP WEBSITES
        */
        // Click handler for "Add a new site" links; insert a "New Site" row into the table.
        $('.addRowSite').click(function () {
            piwikHelper.hideAjaxError();
            $('.addRowSite').toggle();
            

            var numberOfRows = $('table#editSites')[0].rows.length;
            var newRowId = 'rowNew' + numberOfRows;
            var submitButtonHtml = '<input type="submit" class="adduser submit" value="' + _pk_translate('General_Save') + '" />';
            
            var siteNameOptions = '';
            var sites = getSitesAJAX();
            
            $($.parseHTML(' <tr id="' + newRowId + '">\
                <td colspan=2><select id="siteId">' + siteIdOptions + '</select></td>\
                <td>' + submitButtonHtml + '</td>\
                <td><span class="cancel link_but">' + sprintf(_pk_translate('General_OrCancel'), "", "") + '</span></td>\
            </tr>'))
                .appendTo('#editSites')
            ;

            $('.adduser').click(function () {
                sendAddMemberAJAX($('tr#' + newRowId));
            });

            $('.cancel').click(function () {
                piwikHelper.hideAjaxError();
                $(this).parents('tr').remove();
                $('.addRowSite').toggle();
            });
            return false;
        });
        
        // Click handler for "Delete" buttons; ask for confirmation and then delete the website.
        $('.deleteSite').click(function () {
                piwikHelper.hideAjaxError();
                var idRow = $(this).attr('id');

                $('#confirm').find('h2').text(sprintf(_pk_translate('Groups_DeleteConfirmMember'), '"' + $(this).parent().parent().find('.login').html() + '"'));
                piwikHelper.modalConfirm('#confirm', { yes: function () {

                    sendDeleteMemberAJAX($('tr#' + idRow));
                }});
            }
        );
        
        
        /**
        * Shared Listeners
        */
        $('td.editable').click(function (event) {
            $(this).parent().find('.edit').click();
        });
        
    };
    
    
    /**
    * Shared Functions
    */
    function submitUpdate(self) {
        $(self).parent().find('.update').click();
    }
    function submitOnEnter(e) {
        var key = e.keyCode || e.which;
        if (key == 13) {
            submitUpdate(this);
            $(this).parent().find('.submit').click();
        }
    }
    function getSitesAJAX() {
        
    }
    
    
    /**
    * Group Functions
    */
    function sendAddGroupAJAX(row) {
        var groupName = $(row).find('input#groupName').val();
        var maxSites = $(row).find('input#maxsites').val();

        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            module: 'API',
            format: 'json',
            method: 'Groups.addGroup'
        }, 'GET');
        ajaxHandler.addParams({
            groupName: groupName,
            maxSites: maxSites
        }, 'POST');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }
    function sendUpdateGroupAJAX(row) {
        var groupId = $(row).find('.groupId').html();
        var groupName = $(row).find('input#groupName').val();
        var maxSites = $(row).find('input#maxsites').val();

        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            module: 'API',
            format: 'json',
            method: 'Groups.updateGroup',
            groupId: groupId
        }, 'GET');
        ajaxHandler.addParams({
            groupName: groupName,
            maxSites: maxSites,
            groupId: groupId
        }, 'POST');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }
    function sendDeleteGroupAJAX(groupId) {
        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            groupId: groupId,
            module: 'API',
            format: 'json',
            method: 'Groups.deleteGroup'
        }, 'GET');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }

    
    
    
    /**
    * Group Member Functions
    */
    function sendAddMemberAJAX(row) {
        var groupId = $(row).parents('table.entityTable').attr('data-groupId');
        var login = $(row).find('input#login').val();
        var access = $(row).find('select#access').val();
        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            module: 'API',
            format: 'json',
            method: 'Groups.addMember',
            groupId: groupId
        }, 'GET');
        ajaxHandler.addParams({
            login: login,
            access: access
        }, 'POST');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }
    function sendUpdateMemberAJAX(row) {
        var groupId = $(row).parents('table.entityTable').attr('data-groupId');
        var login = $(row).find('td.login').html();
        var access = $(row).find('select#access').val();
        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            module: 'API',
            format: 'json',
            method: 'Groups.updateMember',
            groupId: groupId,
            login: login
        }, 'GET');
        ajaxHandler.addParams({
            login: login,
            access: access
        }, 'POST');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }
    function sendDeleteMemberAJAX(row) {
        var groupId = $(row).parents('table.entityTable').attr('data-groupId');
        var login = $(row).find('.login').html();
        var ajaxHandler = new ajaxHelper();
        ajaxHandler.addParams({
            groupId: groupId,
            module: 'API',
            format: 'json',
            method: 'Groups.deleteMember',
            groupId: groupId,
        }, 'GET');
        ajaxHandler.addParams({
            login: login
        }, 'POST');
        ajaxHandler.redirectOnSuccess();
        ajaxHandler.setLoadingElement();
        ajaxHandler.send(true);
    }
    
    
}